@@ -43,7 +43,11 @@ FicsDialog::FicsDialog ( QWidget* parent, Qt::WindowFlags f ) : QWidget ( parent
 
 	ui->rememberCheckBox->setChecked(Settings::autoLogin());
 
+#if QT_VERSION >= QT_VERSION_CHECK(6, 7, 0)
+	connect ( ui->rememberCheckBox, &QCheckBox::checkStateChanged, this, &FicsDialog::rememberCheckBoxChanged );
+#else
 	connect ( ui->rememberCheckBox, &QCheckBox::stateChanged, this, &FicsDialog::rememberCheckBoxChanged );
+#endif
 }
 
 FicsDialog::~FicsDialog() {
@@ -66,7 +70,7 @@ void FicsDialog::slotSessionStarted() {
 
 void FicsDialog::slotLogin() {
 	setLoginEnabled ( false );
-	setStatus ( i18n("Logging in...") );
+	setStatus ( i18n("Logging in…") );
 	Q_EMIT login ( ui->usernameLineEdit->text(), ui->passwordLineEdit->text() );
 }
 
@@ -220,8 +224,7 @@ bool FicsDialog::rated() {
 	return ui->ratedCheckBox->isChecked();
 }
 
-void FicsDialog::rememberCheckBoxChanged( int state ) {
-	Q_UNUSED(state)
+void FicsDialog::rememberCheckBoxChanged() {
 	Settings::setAutoLogin(ui->rememberCheckBox->isChecked());
 	Settings::self()->save();
 }
